==> better-admin-ui-vue-0.0.1.tgz: package/es/components/FileUpload/FileUpload.js <==
import * as _vue from "vue";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * @Date: 2020/11/24 10:20 上午
 * @Author: Fioanna
 * @Description: 图片上传
 */
import axios from 'axios';
import AUpload from 'ant-design-vue/es/upload';
import AIcon from 'ant-design-vue/es/icon';
import AModal from 'ant-design-vue/es/modal';
import { previewImage } from 'ant-design-vue/es/upload/utils';
import fileUploadProps from './types';
import './style.less';
export default {
  name: 'EFileUpload',
  components: {
    AUpload: AUpload,
    AIcon: AIcon,
    AModal: AModal
  },
  props: fileUploadProps,
  data: function data() {
    return {
      fileList: [],
      // 已经上传的文件列表（受控）
      previewVisible: false,
      // 预览模态是否显示
      previewImage: '',
      // 当前预览的图片
      loading: false,
      // 当前上传是否进行中，如果是进行中则会展示loading的icon
      disabled: true,
      // 是否禁用
      formData: {}
    };
  },
  watch: {
    fileList: function fileList(newVal) {
      var url = newVal && newVal.length > 0 ? newVal[0].url : '';
      this.$emit('input', url);
      this.$emit('change', url);
    },
    ossClient: function ossClient(newVal) {
      if (newVal) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    },
    value: function value() {
      if (this.ossClient !== undefined) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    }
  },
  computed: {
    // ...mapState({
    //   ossClient: state => state.oss.ossClient // 当前store中的ossClient
    // }),
    // ossClient() {
    // return this.$store.getters.oss.ossClient
    // },
    desc: function desc() {
      return this.$data.disabled ? '初始化中...' : this.$props.description;
    },
    action: function action() {
      return "http://".concat(this.ossClient.bucket, ".").concat(this.ossClient.endPoint);
    }
  },
  created: function created() {
    if (this.ossClient !== undefined) {
      this.$data.disabled = false;

      this._handleExistedFileList();
    }
  },
  methods: {
    /**
     * 处理预设的图片
     */
    _handleExistedFileList: function _handleExistedFileList() {
      if (this.value) {
        this.fileList.splice(0);
        var name = this.value; // const targetUrl = this.ossClient.signatureUrl(name)

        var targetUrl = name;
        this.fileList.push({
          url: targetUrl,
          status: 'done',
          uid: new Date().getTime(),
          thumbUrl: targetUrl,
          name: name
        });
      } else {
        if (this.fileList.length > 0) {
          // 如果图片列表有数据则清空
          this.fileList = [];
        }
      }
    },

    /**
     * 处理预览回调
     * @param file 当前点击预览的文件对象
     * @private
     */
    _handlePreview: function _handlePreview(file) {
      this.previewImage = file.thumbUrl;
      this.previewVisible = true;
    },

    /**
     * 处理业务变更
     * @param fileList 已经上传的文件列表
     * @private
     */
    _handleChange: function _handleChange(_ref) {
      var file = _ref.file;

      if (file.status === 'removed') {
        var index = this.fileList.findIndex(function (item) {
          return item.uid === file.uid;
        });

        if (index !== -1) {
          this.fileList.splice(index, 1);
        }
      } else if (file.status === 'uploading') {
        this.$data.loading = true;
      } else if (file.status === 'done') {
        var name = file.name;
        var targetUrl = "".concat(this.action, "/").concat(this.$data.formData.key);
        this.fileList.push({
          url: targetUrl,
          status: 'done',
          uid: new Date().getTime(),
          thumbUrl: targetUrl,
          name: name
        });
        this.$data.loading = false;
        this.$message.success('上传成功');
      }
    },

    /**
     * 取消预览
     * @private
     */
    _handleCancelPreview: function _handleCancelPreview() {
      this.previewVisible = false;
    },

    /**
     * 上传前的处理函数，处理支持的文件类型及大小
     * @param file
     * @return {boolean|boolean}
     * @private
     */
    _handleBeforeUpload: function _handleBeforeUpload(file) {
      var isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';

      if (!isJpgOrPng) {
        this.$message.error('只允许jpeg、png格式图片');
      }

      var isLt2M = file.size / 1024 / 1024 < 2;

      if (!isLt2M) {
        this.$message.error('图片大小不能超过2M');
      }

      if (isJpgOrPng && isLt2M) {
        this.$data.formData = _extends({}, this.ossClient, {
          name: file.name,
          key: this.ossClient.dir + '/' + new Date().getTime() + '.png'
        });
        delete this.$data.formData.dir;
        delete this.$data.formData.endPoint;
        delete this.$data.formData.bucket;
        return true;
      }
    },

    /**
     * 自定义处理上传逻辑函数
     * @param file
     * @private
     */
    _handleCustomRequest: function _handleCustomRequest(file) {
      this._upload(file.file);
    },

    /**
     * 上传
     * @param file
     * @private
     */
    _upload: function _upload(file) {
      var _this = this;

      this.loading = true;
      var data = new FormData();

      for (var key in this.$data.formData) {
        data.append(key, this.$data.formData[key]);
      }

      data.append('file', file);
      var instance = axios.create();
      instance.defaults.headers = {
        'Content-Type': 'multipart/form-data'
      };
      instance.defaults.baseURL = this.action;
      instance.request({
        method: 'post',
        data: data
      }).then(function () {
        var name = file.name; // const targetUrl = client.signatureUrl(name)

        var targetUrl = "".concat(_this.action, "/").concat(_this.$data.formData.key);

        _this.fileList.push({
          url: targetUrl,
          status: 'done',
          uid: new Date().getTime(),
          thumbUrl: targetUrl,
          name: name
        });

        _this.$message.success('上传成功');
      })["catch"](function () {
        _this.$message.error('上传失败');
      })["finally"](function () {
        _this.loading = false;
      });
    }
  },
  render: function render() {
    var _this2 = this;

    var _this$$data = this.$data,
        fileList = _this$$data.fileList,
        formData = _this$$data.formData,
        disabled = _this$$data.disabled,
        loading = _this$$data.loading,
        previewVisible = _this$$data.previewVisible;
    return _vue.createVNode("div", null, [_vue.createVNode(_vue.resolveComponent("a-upload"), {
      "listType": "picture-card",
      "fileList": fileList,
      "data": formData,
      "disabled": disabled,
      "beforeUpload": this._handleBeforeUpload,
      "customRequest": this._handleCustomRequest,
      "onPreview": this._handlePreview,
      "onChange": this._handleChange
    }, {
      "default": function _default() {
        return [fileList.length < 1 ? _vue.createVNode("div", null, [_vue.createVNode(_vue.resolveComponent("a-icon"), {
          "type": loading ? 'loading' : 'plus'
        }, null), _vue.createVNode("div", {
          "className": "ant-upload-text"
        }, [_this2.desc])]) : null];
      }
    }), _vue.createVNode(_vue.resolveComponent("a-modal"), {
      "visible": previewVisible,
      "footer": null,
      "onCancel": this._handleCancelPreview
    }, {
      "default": function _default() {
        return [_vue.createVNode("img", {
          "alt": "example",
          "style": "width: 100%",
          "src": previewImage
        }, null)];
      }
    })]);
  }
};

==> better-admin-ui-vue-0.0.7.tgz: package/es/components/FileUpload/FileUpload.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * @Date: 2020/11/24 10:20 上午
 * @Author: Fioanna
 * @Description: 图片上传
 */
import axios from 'axios';
import AUpload from 'ant-design-vue/es/upload';
import AIcon from 'ant-design-vue/es/icon';
import AModal from 'ant-design-vue/es/modal';
import { previewImage } from 'ant-design-vue/es/upload/utils';
import fileUploadProps from './types';
import './style.less';
export default {
  name: 'EFileUpload',
  props: fileUploadProps,
  data: function data() {
    return {
      fileList: [],
      // 已经上传的文件列表（受控）
      previewVisible: false,
      // 预览模态是否显示
      previewImage: '',
      // 当前预览的图片
      loading: false,
      // 当前上传是否进行中，如果是进行中则会展示loading的icon
      disabled: true,
      // 是否禁用
      formData: {}
    };
  },
  watch: {
    fileList: function fileList(newVal) {
      var url = newVal && newVal.length > 0 ? newVal[0].url : '';
      this.$emit('input', url);
      this.$emit('change', url);
    },
    ossClient: function ossClient(newVal) {
      if (newVal) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    },
    value: function value() {
      if (this.ossClient !== undefined) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    }
  },
  computed: {
    // ...mapState({
    //   ossClient: state => state.oss.ossClient // 当前store中的ossClient
    // }),
    // ossClient() {
    // return this.$store.getters.oss.ossClient
    // },
    desc: function desc() {
      return this.$data.disabled ? '初始化中...' : this.$props.description;
    },
    action: function action() {
      return "http://".concat(this.ossClient.bucket, ".").concat(this.ossClient.endPoint);
    }
  },
  created: function created() {
    if (this.ossClient !== undefined) {
      this.$data.disabled = false;

      this._handleExistedFileList();
    }
  },
  methods: {
    /**
     * 处理预设的图片
     */
    _handleExistedFileList: function _handleExistedFileList() {
      if (this.value) {
        this.fileList.splice(0);
        var name = this.value; // const targetUrl = this.ossClient.signatureUrl(name)

        var targetUrl = name;
        this.fileList.push({
          url: targetUrl,
          status: 'done',
          uid: new Date().getTime(),
          thumbUrl: targetUrl,
          name: name
        });
      } else {
        if (this.fileList.length > 0) {
          // 如果图片列表有数据则清空
          this.fileList = [];
        }
      }
    },

    /**
     * 处理预览回调
     * @param file 当前点击预览的文件对象
     * @private
     */
    _handlePreview: function _handlePreview(file) {
      this.previewImage = file.thumbUrl;
      this.previewVisible = true;
    },

    /**
     * 处理业务变更
     * @param fileList 已经上传的文件列表
     * @private
     */
    _handleChange: function _handleChange(_ref) {
      var file = _ref.file;

      if (file.status === 'removed') {
        var index = this.fileList.findIndex(function (item) {
          return item.uid === file.uid;
        });

        if (index !== -1) {
          this.fileList.splice(index, 1);
        }
      } else if (file.status === 'uploading') {
        this.$data.loading = true;
      } else if (file.status === 'done') {
        var name = file.name;
        var targetUrl = "".concat(this.action, "/").concat(this.$data.formData.key);
        this.fileList.push({
          url: targetUrl,
          status: 'done',
          uid: new Date().getTime(),
          thumbUrl: targetUrl,
          name: name
        });
        this.$data.loading = false;
        this.$message.success('上传成功');
      }
    },

    /**
     * 取消预览
     * @private
     */
    _handleCancelPreview: function _handleCancelPreview() {
      this.previewVisible = false;
    },

    /**
     * 上传前的处理函数，处理支持的文件类型及大小
     * @param file
     * @return {boolean|boolean}
     * @private
     */
    _handleBeforeUpload: function _handleBeforeUpload(file) {
      var isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';

      if (!isJpgOrPng) {
        this.$message.error('只允许jpeg、png格式图片');
      }

      var isLt2M = file.size / 1024 / 1024 < 2;

      if (!isLt2M) {
        this.$message.error('图片大小不能超过2M');
      }

      if (isJpgOrPng && isLt2M) {
        this.$data.formData = _extends({}, this.ossClient, {
          name: file.name,
          key: this.ossClient.dir + '/' + new Date().getTime() + '.png'
        });
        delete this.$data.formData.dir;
        delete this.$data.formData.endPoint;
        delete this.$data.formData.bucket;
        return true;
      }
    },

    /**
     * 自定义处理上传逻辑函数
     * @param file
     * @private
     */
    _handleCustomRequest: function _handleCustomRequest(file) {
      this._upload(file.file);
    },

    /**
     * 上传
     * @param file
     * @private
     */
    _upload: function _upload(file) {
      var _this = this;

      this.loading = true;
      var data = new FormData();

      for (var key in this.$data.formData) {
        data.append(key, this.$data.formData[key]);
      }

      data.append('file', file);
      var instance = axios.create();
      instance.defaults.headers = {
        'Content-Type': 'multipart/form-data'
      };
      instance.defaults.baseURL = this.action;
      instance.request({
        method: 'post',
        data: data
      }).then(function () {
        var name = file.name; // const targetUrl = client.signatureUrl(name)

        var targetUrl = "".concat(_this.action, "/").concat(_this.$data.formData.key);

        _this.fileList.push({
          url: targetUrl,
          status: 'done',
          uid: new Date().getTime(),
          thumbUrl: targetUrl,
          name: name
        });

        _this.$message.success('上传成功');
      })["catch"](function () {
        _this.$message.error('上传失败');
      })["finally"](function () {
        _this.loading = false;
      });
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$data = this.$data,
        fileList = _this$$data.fileList,
        formData = _this$$data.formData,
        disabled = _this$$data.disabled,
        loading = _this$$data.loading,
        previewVisible = _this$$data.previewVisible;
    return h("div", [h(AUpload, {
      attrs: {
        listType: "picture-card",
        fileList: fileList,
        data: formData,
        disabled: disabled,
        beforeUpload: this._handleBeforeUpload,
        customRequest: this._handleCustomRequest
      },
      on: {
        "preview": this._handlePreview,
        "change": this._handleChange
      }
    }, [fileList.length < 1 ? h("div", [h(AIcon, {
      attrs: {
        type: loading ? 'loading' : 'plus'
      }
    }), h("div", {
      attrs: {
        className: "ant-upload-text"
      }
    }, [this.desc])]) : null]), h(AModal, {
      attrs: {
        visible: previewVisible,
        footer: null
      },
      on: {
        "cancel": this._handleCancelPreview
      }
    }, [h("img", {
      attrs: {
        alt: "example",
        src: previewImage
      },
      style: "width: 100%"
    })])]);
  }
};
